@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.1.3'
+__version__   = '2.1.5'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2021-June-17'   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.3.html'
+__date__      = '2021-September-6'   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.5.html'
 __copyright__ = "(C) 2021 Avinash Kak. Python Software Foundation."
 
 
